@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1400';
+our $VERSION = '0.1401';
 
 use strict;
 use warnings;
@@ -393,7 +393,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1400
+version 0.1401
 
 =head1 SYNOPSIS
 
@@ -477,9 +477,9 @@ determines if a time-stamp or the number of seconds should be returned.
     random => $random,
   );
 
-Return a list of B<N> random numbers within a range.  The B<start>, B<end>,
-B<prec>ision, and whether we want B<random> or sequential numbers are all
-optional.  The defaults are:
+Return a list of numbers within the range defined by B<start> and B<end>.  The
+B<start>, B<end>, B<prec>ision, and whether we want B<random> or sequential
+numbers are all optional.  The defaults are:
 
   start:     1
   end:       10
